==> shards-ui-1.1.1.tgz: package/README.md <==
<p align="center" style="margin-bottom: 40px;">
<img src="logo.jpg" width="250" />
</p>

![Price](https://img.shields.io/badge/Price-FREE-brightgreen.svg)
![Size](https://img.shields.io/badge/Size-12.41_kb_min/gz-brightgreen.svg)
![License](https://img.shields.io/badge/License-MIT-brightgreen.svg)

Shards is a **free** and modern UI kit that comes packed with **2 pre-built pages** and **11 extra custom components** that you can use to kick off your next project.

[![Social - Twitter Share](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?url=https://designrevision.com/downloads/shards&text=I%20love%20the%20free%20Shards%20UI%20kit%20based%20on%20%23bootstrap%20by%20%40DesignRevision%20%23ui%20%23kit%20%23freebie%20) [![Social - Twitter Follow](https://img.shields.io/twitter/follow/DesignRevision.svg?style=social&label=Follow)](https://twitter.com/designrevision)

## Quick Links

* **Demo Pages**
  * [**Components Demo**](https://designrevision.com/demo/shards/)
  * [**App Promo Page**](https://designrevision.com/demo/shards/extra/app-promo.html)
  * [**Agency Landing Page**](https://designrevision.com/demo/shards/extra/agency-landing.html)
* [**Documentation**](https://designrevision.com/docs/shards)
* [**Product Page**](https://designrevision.com/downloads/shards)

## Getting Started

The following instructions will help you get started with Shards.

### 📦 Download
Currently there are only two ways of downloading Shards:
* [Official Website](https://designrevision.com/download/shards)
* [Release Package](https://github.com/DesignRevision/shards-ui/releases)

### 🖇 Dependencies

The only hard dependency is Bootstrap 4 beta which needs to be included in your HTML document before Shards. Datepickers and slider controls also require the Shards JavaScript dependency.

### 🏎💨 Quick Start

In order to take advantage of both Bootstrap and Shards' features you may want to use the following starter template that includes all dependencies.

```html
<!doctype html>
<html lang="en">
  <head>
    <title>Shards — Quick Start</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- Bootstrap and Shards CSS -->
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/css/bootstrap.min.css" integrity="sha384-PsH8R72JQ3SOdhVi3uxftmaW6Vc51MKb0q5P2rRUpPvrszuE4W1povHYgTpBfshb" crossorigin="anonymous">
    <link rel="stylesheet" href="/css/shards.min.css">
  </head>
  <body>
    <h1>👋 Hello! I'm using Shards and it's awesome!</h1>

    <!-- JavaScript -->
    <!-- jQuery, Popper.js, Bootstrap JS, Shards JS -->
    <script src="https://code.jquery.com/jquery-3.2.1.slim.min.js" integrity="sha384-KJ3o2DKtIkvYIK3UENzmM7KCkRr/rE9/Qpg6aAZGJwFDMVNA/GpGFF93hXpG5KkN" crossorigin="anonymous"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.3/umd/popper.min.js" integrity="sha384-vFJXuSJphROIrBnz7yo7oB41mKfc8JzQZiCq4NCceLEaO4IHwicKwpJf9c9IpFgh" crossorigin="anonymous"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta.2/js/bootstrap.min.js" integrity="sha384-alpBpkh1PFOepccYVYDB4do5UnbKysX5WZXm3XxPqe5iKTfUKjNkCk9SaVuEZflJ" crossorigin="anonymous"></script>
    <script src="/js/shards.min.js"></script>
  </body>
</html>
```
## Built With

* [Bootstrap Datepicker by Stefan Petre and Andrew Rowls (Apache 2.0)](https://github.com/uxsolutions/bootstrap-datepicker)
* [noUiSlider by Léon Gersen (WTFPL License)](https://refreshless.com/nouislider/download/)
* [Material Icons](http://material.io/icons)
* [FontAwesome Icons](http://fontawesome.io)

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## 💁 Feedback
Building better products is something I'm trying to get really good at. I’d love to hear more about how you plan on using Shards and what features you consider important in similar products. If you could spare a few minutes, please fill out [this Google Form](https://docs.google.com/forms/d/e/1FAIpQLScyj8F-fyVlb-AAeM-UFXSpDgrfdC81yWm1BNF8_gVCpXN8jw/viewform?usp=sf_link) to help me better understand your current context and what I could do to improve my products.

## Acknowledgments

While building this project we used various free resources built and made 
available by some wonderful people around the world. See the [ATTRIB.md](ATTRIB.md) file for details.

## Roadmap
Below are a couple of items from my list of improvements for the upcoming month(s).

### General
- [x] Publish as an NPM package.
- [x] Change the license to a more permissive alternative.

### Design
- [ ] Improve the Sketch document (nested symbols).

==> shards-ui-2.0.1.tgz: package/README.md <==
<p align="center" style="margin-bottom: 40px;">
<img src="logo.jpg" width="250" />
</p>

![Price](https://img.shields.io/badge/Price-FREE-brightgreen.svg)
![Size](https://img.shields.io/badge/Size-12.41_kb_min/gz-brightgreen.svg)
![License](https://img.shields.io/badge/License-MIT-brightgreen.svg)

Shards is a **free** and modern UI kit that comes packed with **2 pre-built pages** and **11 extra custom components** that you can use to kick off your next project.

[![Social - Twitter Share](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?url=https://designrevision.com/downloads/shards&text=I%20love%20the%20free%20Shards%20UI%20kit%20based%20on%20%23bootstrap%20by%20%40DesignRevision%20%23ui%20%23kit%20%23freebie%20) [![Social - Twitter Follow](https://img.shields.io/twitter/follow/DesignRevision.svg?style=social&label=Follow)](https://twitter.com/designrevision)

## Quick Links

* **Demo Pages**
  * [**Components Demo**](https://designrevision.com/demo/shards/)
  * [**App Promo Page**](https://designrevision.com/demo/shards/extra/app-promo.html)
  * [**Agency Landing Page**](https://designrevision.com/demo/shards/extra/agency-landing.html)
* [**Documentation**](https://designrevision.com/docs/shards)
* [**Product Page**](https://designrevision.com/downloads/shards)

## Getting Started

The following instructions will help you get started with Shards.

### 📦 Download
Currently there are only two ways of downloading Shards:
* [Official Website](https://designrevision.com/download/shards)
* [Release Package](https://github.com/DesignRevision/shards-ui/releases)

### 🖇 Dependencies

The only hard dependency is Bootstrap 4 (final) which needs to be included in your HTML document before Shards. Datepickers and slider controls also require the Shards JavaScript dependency.

### 🏎💨 Quick Start

In order to take advantage of both Bootstrap and Shards' features you may want to use the following starter template that includes all dependencies.

```html
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- CSS Dependencies -->
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" integrity="sha384-Gn5384xqQ1aoWXA+058RXPxPg6fy4IWvTNh0E263XmFcJlSAwiGgFAW/dAiS6JXm" crossorigin="anonymous">
    <link rel="stylesheet" href="css/shards.min.css">
  </head>
  <body>
    <h1>Hello, world!</h1>

    <!-- Optional JavaScript -->
    <!-- JavaScript Dependencies: jQuery, Popper.js, Bootstrap JS, Shards JS -->
    <script src="https://code.jquery.com/jquery-3.2.1.slim.min.js" integrity="sha384-KJ3o2DKtIkvYIK3UENzmM7KCkRr/rE9/Qpg6aAZGJwFDMVNA/GpGFF93hXpG5KkN" crossorigin="anonymous"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js" integrity="sha384-ApNbgh9B+Y1QKtv3Rn7W3mgPxhU9K/ScQsAP7hUibX39j7fakFPskvXusvfa0b4Q" crossorigin="anonymous"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js" integrity="sha384-JZR6Spejh4U02d8jOt6vLEHfe/JQGiRRSQQxSfFWpi1MquVdAyjUar5+76PVCmYl" crossorigin="anonymous"></script>
    <script src="js/shards.min.js"></script>
  </body>
</html>
```
## Built With

* [Bootstrap Datepicker by Stefan Petre and Andrew Rowls (Apache 2.0)](https://github.com/uxsolutions/bootstrap-datepicker)
* [noUiSlider by Léon Gersen (WTFPL License)](https://refreshless.com/nouislider/download/)
* [Material Icons](http://material.io/icons)
* [FontAwesome Icons](http://fontawesome.io)

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## 💁 Feedback
Building better products is something I'm trying to get really good at. I’d love to hear more about how you plan on using Shards and what features you consider important in similar products. If you could spare a few minutes, please fill out [this Google Form](https://docs.google.com/forms/d/e/1FAIpQLScyj8F-fyVlb-AAeM-UFXSpDgrfdC81yWm1BNF8_gVCpXN8jw/viewform?usp=sf_link) to help me better understand your current context and what I could do to improve my products.

## Acknowledgments

While building this project we used various free resources built and made 
available by some wonderful people around the world. See the [ATTRIB.md](ATTRIB.md) file for details.

## Changelog

[View notable changes.](CHANGELOG.md)
